use std::fmt::Display;
use std::io;

#[derive(Debug)]
pub enum BinError {
    UnpackError(String),
    IOError(io::Error),
    Cancelled,
}

impl Display for BinError {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        match self {
            BinError::UnpackError(e) => write!(f, "Unpack error: {}", e),
            BinError::IOError(e) => write!(f, "IO error: {}", e),
            BinError::Cancelled => write!(f, "Cancelled by user"),
        }
    }
}

#[derive(Debug)]
pub enum BuildError {
    InvalidManifest(String),
}

impl Display for BuildError {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        match self {
            _ => write!(f, "Build error"),
        }
    }
}

#[derive(Debug)]
pub enum InstallError {
    BuildError(BuildError),
    BinError(BinError),
    InvalidManifest(String),
}

impl ToString for InstallError {
    fn to_string(&self) -> String {
        match self {
            InstallError::BuildError(e) => format!("{}", e),
            InstallError::BinError(e) => format!("{}", e),
            InstallError::InvalidManifest(s) => format!("{}", s),
        }
    }
}
